Zutto Dokushin de Iru Tsumori？ - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Zutto Dokushin de Iru Tsumori？

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Momoko%20Fukuda%20-%20%E3%81%9A%E3%81%A3%E3%81%A8%E7%8B%AC%E8%BA%AB%E3%81%A7%E3%81%84%E3%82%8B%E3%81%A4%E3%82%82%E3%82%8A.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | Momoko Fukuda - ずっと独身でいるつもり.srt | 2.00 B | 03 Jan 2026 16:00:40
2 | Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.srt | 2.00 B | 03 Jan 2026 16:00:46

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.ass'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.ass | 2.00 B | 03 Jan 2026 16:00:43

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Momoko%20Fukuda%20-%20%E3%81%9A%E3%81%A3%E3%81%A8%E7%8B%AC%E8%BA%AB%E3%81%A7%E3%81%84%E3%82%8B%E3%81%A4%E3%82%82%E3%82%8A.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Zutto%20Dokushin%20de%20Iru%20Tsumori%EF%BC%9F/Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | Momoko Fukuda - ずっと独身でいるつもり.srt | 2.00 B | 03 Jan 2026 16:00:40
2 | Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.ass | 2.00 B | 03 Jan 2026 16:00:43
3 | Zutto.Dokushin.de.Iru.Tsumori.2021.1080p.AMZN.WEB-DL.DDP5.1.H.264-MagicStar.srt | 2.00 B | 03 Jan 2026 16:00:46

Upload new files — Search MDL — Back to Index